Tvg_Fill_Rule

Enum Tvg_Fill_Rule 

#[repr(u32)]
pub enum Tvg_Fill_Rule { TVG_FILL_RULE_NON_ZERO = 0, TVG_FILL_RULE_EVEN_ODD = 1, }
@brief Enumeration specifying the algorithm used to establish which parts of the shape are treated as the inside of the shape.

Variants



TVG_FILL_RULE_NON_ZERO = 0

< A line from the point to a location outside the shape is drawn. The intersections of the line with the path segment of the shape are counted. Starting from zero, if the path segment of the shape crosses the line clockwise, one is added, otherwise one is subtracted. If the resulting sum is non zero, the point is inside the shape.



TVG_FILL_RULE_EVEN_ODD = 1

< A line from the point to a location outside the shape is drawn and its intersections with the path segments of the shape are counted. If the number of intersections is an odd number, the point is inside the shape.