#[repr(u32)]pub enum Tvg_Stroke_Cap {
TVG_STROKE_CAP_BUTT = 0,
TVG_STROKE_CAP_ROUND = 1,
TVG_STROKE_CAP_SQUARE = 2,
}Expand description
@brief Enumeration determining the ending type of a stroke in the open sub-paths.
Variants
TVG_STROKE_CAP_BUTT = 0
< The stroke ends exactly at each of the two endpoints of a sub-path. For zero length sub-paths no stroke is rendered.
TVG_STROKE_CAP_ROUND = 1
< The stroke is extended in both endpoints of a sub-path by a half circle, with a radius equal to the half of a stroke width. For zero length sub-paths a full circle is rendered.
TVG_STROKE_CAP_SQUARE = 2
< The stroke is extended in both endpoints of a sub-path by a rectangle, with the width equal to the stroke width and the length equal to the half of the stroke width. For zero length sub-paths the square is rendered with the size of the stroke width.