#[repr(u32)]pub enum Tvg_Stroke_Fill {
TVG_STROKE_FILL_PAD = 0,
TVG_STROKE_FILL_REFLECT = 1,
TVG_STROKE_FILL_REPEAT = 2,
}Expand description
@brief Enumeration specifying how to fill the area outside the gradient bounds.
Variants
TVG_STROKE_FILL_PAD = 0
< The remaining area is filled with the closest stop color.
TVG_STROKE_FILL_REFLECT = 1
< The gradient pattern is reflected outside the gradient area until the expected region is filled.
TVG_STROKE_FILL_REPEAT = 2
< The gradient pattern is repeated continuously beyond the gradient area until the expected region is filled.