#[repr(u32)]pub enum Tvg_Type {
TVG_TYPE_UNDEF = 0,
TVG_TYPE_SHAPE = 1,
TVG_TYPE_SCENE = 2,
TVG_TYPE_PICTURE = 3,
TVG_TYPE_TEXT = 4,
TVG_TYPE_LINEAR_GRAD = 10,
TVG_TYPE_RADIAL_GRAD = 11,
}Expand description
@brief Enumeration indicating the ThorVG object type value.
ThorVG’s drawing objects can return object type values, allowing you to identify the specific type of each object.
@ingroup ThorVGCapi_Paint
@see tvg_paint_get_type() @see tvg_gradient_get_type()
@since 1.0
Variants
TVG_TYPE_UNDEF = 0
< Undefined type.
TVG_TYPE_SHAPE = 1
< A shape type paint.
TVG_TYPE_SCENE = 2
< A scene type paint.
TVG_TYPE_PICTURE = 3
< A picture type paint.
TVG_TYPE_TEXT = 4
< A text type paint.
TVG_TYPE_LINEAR_GRAD = 10
< A linear gradient type.
TVG_TYPE_RADIAL_GRAD = 11
< A radial gradient type.