tvg_gradient_set_transform

Function tvg_gradient_set_transform 

pub unsafe extern "C" fn tvg_gradient_set_transform(
    grad: Tvg_Gradient,
    m: *const Tvg_Matrix,
) -> Tvg_Result
@brief Sets the matrix of the affine transformation for the gradient object.

The augmented matrix of the transformation is expected to be given.

@param[in] grad The Tvg_Gradient object to be transformed. @param[in] m The 3x3 augmented matrix.