#[repr(C)]pub struct Tvg_Color_Stop {
pub offset: f32,
pub r: u8,
pub g: u8,
pub b: u8,
pub a: u8,
}Expand description
@brief A data structure storing the information about the color and its relative position inside the gradient bounds.
Fields
offset: f32< The relative position of the color.
r: u8< The red color channel value in the range [0 ~ 255].
g: u8< The green color channel value in the range [0 ~ 255].
b: u8< The blue color channel value in the range [0 ~ 255].
a: u8< The alpha channel value in the range [0 ~ 255], where 0 is completely transparent and 255 is opaque.