Tvg_Canvas

Type Alias Tvg_Canvas 

pub type Tvg_Canvas = *mut _Tvg_Canvas;
@brief A structure responsible for managing and drawing graphical elements.

It sets up the target buffer, which can be drawn on the screen. It stores the Tvg_Paint objects (Shape, Scene, Picture).