#[repr(u32)]pub enum Tvg_Result {
TVG_RESULT_SUCCESS = 0,
TVG_RESULT_INVALID_ARGUMENT = 1,
TVG_RESULT_INSUFFICIENT_CONDITION = 2,
TVG_RESULT_FAILED_ALLOCATION = 3,
TVG_RESULT_MEMORY_CORRUPTION = 4,
TVG_RESULT_NOT_SUPPORTED = 5,
TVG_RESULT_UNKNOWN = 255,
}Expand description
@brief Enumeration specifying the result from the APIs.
All ThorVG APIs could potentially return one of the values in the list. Please note that some APIs may additionally specify the reasons that trigger their return values.
Variants
TVG_RESULT_SUCCESS = 0
< The value returned in case of a correct request execution.
TVG_RESULT_INVALID_ARGUMENT = 1
< The value returned in the event of a problem with the arguments given to the API - e.g. empty paths or null pointers.
TVG_RESULT_INSUFFICIENT_CONDITION = 2
< The value returned in case the request cannot be processed - e.g. asking for properties of an object, which does not exist.
TVG_RESULT_FAILED_ALLOCATION = 3
< The value returned in case of unsuccessful memory allocation.
TVG_RESULT_MEMORY_CORRUPTION = 4
< The value returned in the event of bad memory handling - e.g. failing in pointer releasing or casting
TVG_RESULT_NOT_SUPPORTED = 5
< The value returned in case of choosing unsupported engine features(options).
TVG_RESULT_UNKNOWN = 255
< The value returned in all other cases.