#[repr(u32)]pub enum Tvg_Stroke_Join {
TVG_STROKE_JOIN_MITER = 0,
TVG_STROKE_JOIN_ROUND = 1,
TVG_STROKE_JOIN_BEVEL = 2,
}Expand description
@brief Enumeration specifying how to fill the area outside the gradient bounds.
Variants
TVG_STROKE_JOIN_MITER = 0
< The outer corner of the joined path segments is spiked. The spike is created by extension beyond the join point of the outer edges of the stroke until they intersect. In case the extension goes beyond the limit, the join style is converted to the Bevel style.
TVG_STROKE_JOIN_ROUND = 1
< The outer corner of the joined path segments is rounded. The circular region is centered at the join point.
TVG_STROKE_JOIN_BEVEL = 2
< The outer corner of the joined path segments is bevelled at the join point. The triangular region of the corner is enclosed by a straight line between the outer corners of each stroke.