pub unsafe extern "C" fn tvg_gradient_get_transform(
grad: Tvg_Gradient,
m: *mut Tvg_Matrix,
) -> Tvg_ResultExpand description
@brief Gets the matrix of the affine transformation of the gradient object.
In case no transformation was applied, the identity matrix is set.
@param[in] grad The Tvg_Gradient object of which to get the transformation matrix. @param[out] m The 3x3 augmented matrix.