pub type Tvg_Canvas = *mut _Tvg_Canvas;Expand description
@brief A structure responsible for managing and drawing graphical elements.
It sets up the target buffer, which can be drawn on the screen. It stores the Tvg_Paint objects (Shape, Scene, Picture).